@@ -85,6 +85,9 @@ void notification_suppress_messages (NotifyNotification *n, gchar *action, gpoin
 
 void quick_message_notify (gchar *message);
 void quick_message (gchar *message);
+void quick_message_dialog (gchar *message);
+gboolean quick_message_with_checkbox (gchar *message, gchar *checkboxtext);
+
 void read_disks_netcat (t_chip *chip);
 void read_disks_linux26 (t_chip *chip);
 int get_hddtemp_d_str (char *buffer, size_t bufsize);
@@ -140,7 +143,7 @@ void quick_message_dialog (gchar *message)
                                   GTK_DIALOG_DESTROY_WITH_PARENT,
                                   GTK_MESSAGE_INFO,
                                   GTK_BUTTONS_CLOSE,
-                                  message);
+                                  message, NULL);
 
     /* dialog = gtk_dialog_new_with_buttons (_("Could not run \"hddtemp\""),
                                          NULL, 0, // GTK DIALOG NO MODAL ;-)
@@ -172,7 +175,7 @@ gboolean quick_message_with_checkbox (gchar *message, gchar *checkboxtext) {
                                   0, /* GTK_DIALOG_DESTROY_WITH_PARENT */
                                   GTK_MESSAGE_INFO,
                                   GTK_BUTTONS_CLOSE,
-                                  message);
+                                  message, NULL);
 
     gtk_window_set_title(GTK_WINDOW(dialog), _("Sensors Plugin"));
 
@@ -213,9 +216,10 @@ read_disks_netcat (t_chip *chip)
     size_t result;
 
     t_chipfeature *cf;
-
+    
+    bzero(&reply, REPLY_MAX_SIZE);
     result = get_hddtemp_d_str(reply, REPLY_MAX_SIZE);
-    DBG ("reply=%s\n", reply);
+    DBG ("reply=%s with result=%d\n", reply, (int) result);
 
     tmp = str_split (reply, DOUBLE_DELIMITER);
     do {
@@ -385,8 +389,11 @@ populate_detected_drives (t_chip *chip)
 int
 initialize_hddtemp (GPtrArray *chips, gboolean *suppressmessage)
 {
-    int generation, major, result, retval;
-    struct utsname *p_uname;
+#ifndef HAVE_NETCAT
+    int generation, major, result;
+#endif
+    int retval;
+    //struct utsname *p_uname;
     t_chip *chip;
 
     g_assert (chips!=NULL);
@@ -404,7 +411,9 @@ initialize_hddtemp (GPtrArray *chips, gboolean *suppressmessage)
     chip->name = g_strdup(_("Hard disks"));
     chip->sensorId = g_strdup("Hard disks");
     chip->type = HDD;
-
+#ifdef HAVE_NETCAT
+    read_disks_netcat (chip);
+#else
     p_uname = (struct utsname *) malloc (sizeof(struct utsname));
     result =  uname (p_uname);
     if (result!=0) {
@@ -418,16 +427,15 @@ initialize_hddtemp (GPtrArray *chips, gboolean *suppressmessage)
 
     /* Note: This is actually supposed to be carried out by ifdef HAVE_LINUX
      and major/minor number stuff from compile time*/
-#ifdef HAVE_NETCAT
-    read_disks_netcat (chip);
-#else
-    if (strcmp(p_uname->sysname, "Linux")==0 && major>=5)
+
+    if (strcmp(p_uname->sysname, "Linux")==0 && (generation>=3 || (generation==2 && major>=5))) 
         read_disks_linux26 (chip);
     else
         read_disks_fallback (chip); /* hopefully, that's a safe variant */
+    
+    g_free(p_uname);
 #endif
 
-    g_free(p_uname);
 
     remove_unmonitored_drives (chip, suppressmessage);
     DBG  ("numfeatures=%d\n", chip->num_features);
@@ -459,7 +467,7 @@ get_hddtemp_d_str (char *buffer, size_t bufsize)
     /* Create the socket. */
     sock = socket(PF_INET, SOCK_STREAM, 0);
     if (sock < 0) {
-	    return -1;
+      return -1;
     }
 
     /* Connect to the server. */
@@ -467,14 +475,14 @@ get_hddtemp_d_str (char *buffer, size_t bufsize)
     servername.sin_port = htons(HDDTEMP_PORT);
     hostinfo = gethostbyname("localhost");
     if (hostinfo == NULL) {
-/*	fprintf (stderr, "Unknown host %s.\n", hostname);*/
-	    return -1;
+/*  fprintf (stderr, "Unknown host %s.\n", hostname);*/
+      return -1;
     }
     servername.sin_addr = *(struct in_addr *) hostinfo->h_addr;
 
     if (connect (sock, (struct sockaddr *) &servername, sizeof (servername)) < 0) {
-/*	perror ("connect (client)");*/
-	    return -1;
+/*  perror ("connect (client)");*/
+      return -1;
     }
 
     /* Read data from server. */
@@ -482,7 +490,7 @@ get_hddtemp_d_str (char *buffer, size_t bufsize)
       nchunk = read(sock, buffer+nbytes, bufsize-nbytes-1);
       if (nchunk < 0) {
           /* Read error. */
-    /*	    perror ("read");*/
+    /*      perror ("read");*/
           close (sock);
           return -1;
       } else if (nchunk == 0) {
@@ -516,10 +524,13 @@ get_hddtemp_value (char* disk, gboolean *suppressmessage)
 
 #ifdef HAVE_NETCAT
     gchar *tmp, *tmp2, *tmp3;
-		char reply[REPLY_MAX_SIZE];
-    size_t read_size;
+    char reply[REPLY_MAX_SIZE];
+    //size_t read_size;
 #endif
 
+    if (disk==NULL)
+      return 0.0;
+
     if (suppressmessage!=NULL)
         nevershowagain = *suppressmessage;
     else
@@ -536,7 +547,8 @@ get_hddtemp_value (char* disk, gboolean *suppressmessage)
     error->message = g_strdup (_("No concrete error detected.\n"));
     if (exit_status==0)
 */
-    read_size = get_hddtemp_d_str(reply, REPLY_MAX_SIZE);
+    bzero(&reply, REPLY_MAX_SIZE);
+    get_hddtemp_d_str(reply, REPLY_MAX_SIZE);
 
     {
         tmp3 = "-255";
